@@ -239,7 +239,8 @@ void apply_screen_info_token(char *token, char *value, void *data)
  *   "mode_name"  dot_clock  timings  flags
  *
  **/
-static nvModeLinePtr modeline_parse(const char *modeline_str,
+static nvModeLinePtr modeline_parse(nvDisplayPtr display,
+                                    const char *modeline_str,
                                     const int broken_doublescan_modelines)
 {
     nvModeLinePtr modeline = NULL;
@@ -356,40 +357,57 @@ static nvModeLinePtr modeline_parse(const char *modeline_str,
         free(tmp);
     }
 
-
-    /*
-     * Calculate the vertical refresh rate of the modeline in Hz;
-     * divide by two for double scan modes (if the double scan
-     * modeline isn't broken; i.e., already has a correct vtotal), and
-     * multiply by two for interlaced modes (so that we report the
-     * field rate, rather than the frame rate)
-     */
-
-    htotal = (double) modeline->data.htotal;
-    vtotal = (double) modeline->data.vtotal;
-
-    pclk = strtod(modeline->data.clock, &nptr);
-
-    if ((pclk == 0.0) || !nptr || *nptr != '\0' || ((htotal * vtotal) == 0)) {
-        nv_warning_msg("Failed to compute the refresh rate "
-                       "for the modeline '%s'", str);
-        goto fail;
+    modeline->refresh_rate = 0;
+    if (display->is_sdi && display->gpu->num_gvo_modes) {
+        /* Fetch the SDI refresh rate of the mode from the gvo mode table */
+        int i;
+        for (i = 0; i < display->gpu->num_gvo_modes; i++) {
+            if (display->gpu->gvo_mode_data[i].id &&
+                display->gpu->gvo_mode_data[i].name &&
+                !strcmp(display->gpu->gvo_mode_data[i].name,
+                        modeline->data.identifier)) {
+                modeline->refresh_rate = display->gpu->gvo_mode_data[i].rate;
+                modeline->refresh_rate /= 1000.0;
+                break;
+            }
+        }
     }
 
-    modeline->refresh_rate = (pclk * 1000000.0) / (htotal * vtotal);
+    if (modeline->refresh_rate == 0) {
+        /*
+         * Calculate the vertical refresh rate of the modeline in Hz;
+         * divide by two for double scan modes (if the double scan
+         * modeline isn't broken; i.e., already has a correct vtotal), and
+         * multiply by two for interlaced modes (so that we report the
+         * field rate, rather than the frame rate)
+         */
 
-    factor = 1.0;
+        htotal = (double) modeline->data.htotal;
+        vtotal = (double) modeline->data.vtotal;
 
-    if ((modeline->data.flags & V_DBLSCAN) && !broken_doublescan_modelines) {
-        factor *= 0.5;
+        pclk = strtod(modeline->data.clock, &nptr);
+
+        if ((pclk == 0.0) || !nptr || *nptr != '\0' || ((htotal * vtotal) == 0)) {
+            nv_warning_msg("Failed to compute the refresh rate "
+                           "for the modeline '%s'", str);
+            goto fail;
+        }
+
+        modeline->refresh_rate = (pclk * 1000000.0) / (htotal * vtotal);
+
+        factor = 1.0;
+
+        if ((modeline->data.flags & V_DBLSCAN) && !broken_doublescan_modelines) {
+            factor *= 0.5;
+        }
+
+        if (modeline->data.flags & V_INTERLACE) {
+            factor *= 2.0;
+        }
+
+        modeline->refresh_rate *= factor;
     }
 
-    if (modeline->data.flags & V_INTERLACE) {
-        factor *= 2.0;
-    }
-
-    modeline->refresh_rate *= factor;
-
     /* Restore the locale */
     if (old_locale) {
         setlocale(LC_NUMERIC, old_locale);
@@ -921,7 +939,7 @@ Bool display_add_modelines_from_server(nvDisplayPtr display, gchar **err_str)
     str = modeline_strs;
     while (strlen(str)) {
 
-        modeline = modeline_parse(str, broken_doublescan_modelines);
+        modeline = modeline_parse(display, str, broken_doublescan_modelines);
         if (!modeline) {
             *err_str = g_strdup_printf("Failed to parse the following "
                                        "modeline of display device\n"
@@ -937,8 +955,8 @@ Bool display_add_modelines_from_server(nvDisplayPtr display, gchar **err_str)
         }
 
         /* Add the modeline at the end of the display's modeline list */
-        display->modelines = (nvModeLinePtr)xconfigAddListItem
-            ((GenericListPtr)display->modelines, (GenericListPtr)modeline);
+        xconfigAddListItem((GenericListPtr *)(&display->modelines),
+                           (GenericListPtr)modeline);
         display->num_modelines++;
 
         /* Get next modeline string */
@@ -1243,9 +1261,8 @@ static Bool screen_add_metamode(nvScreenPtr screen, char *metamode_str,
 
 
     /* Add the metamode at the end of the screen's metamode list */
-    screen->metamodes =
-        (nvMetaModePtr)xconfigAddListItem((GenericListPtr)screen->metamodes,
-                                          (GenericListPtr)metamode);
+    xconfigAddListItem((GenericListPtr *)(&screen->metamodes),
+                       (GenericListPtr)metamode);
 
 
     /* Split up the metamode into separate modes */
@@ -1316,9 +1333,8 @@ static Bool screen_add_metamode(nvScreenPtr screen, char *metamode_str,
         
 
         /* Add the mode at the end of the display's mode list */
-        display->modes =
-            (nvModePtr)xconfigAddListItem((GenericListPtr)display->modes,
-                                          (GenericListPtr)mode);
+        xconfigAddListItem((GenericListPtr *)(&display->modes),
+                           (GenericListPtr)mode);
         display->num_modes++;
         
     } /* Done parsing a single metamode */
@@ -1391,9 +1407,8 @@ static Bool screen_check_metamodes(nvScreenPtr screen)
             }
 
             /* Add the mode at the end of display's mode list */
-            display->modes =
-                (nvModePtr)xconfigAddListItem((GenericListPtr)display->modes,
-                                              (GenericListPtr)mode);
+            xconfigAddListItem((GenericListPtr *)(&display->modes),
+                               (GenericListPtr)mode);
             display->num_modes++;
 
             metamode = metamode->next;
@@ -1651,9 +1666,8 @@ void gpu_remove_and_free_display(nvDisplayPtr display)
         }
 
         /* Remove the display from the GPU */
-        gpu->displays =
-            (nvDisplayPtr)xconfigRemoveListItem((GenericListPtr)gpu->displays,
-                                                (GenericListPtr)display);
+        xconfigRemoveListItem((GenericListPtr *)(&gpu->displays),
+                              (GenericListPtr)display);
         gpu->connected_displays &= ~(display->device_mask);
         gpu->num_displays--;
     }
@@ -1688,6 +1702,48 @@ static void gpu_remove_displays(nvGpuPtr gpu)
 
 
 
+/** gpu_query_gvo_mode_info() ****************************************
+ *
+ * Adds GVO mode information to the GPU's gvo mode data table at
+ * the given table index.
+ *
+ **/
+static Bool gpu_query_gvo_mode_info(nvGpuPtr gpu, int mode_id, int table_idx)
+{
+    ReturnStatus ret1, ret2;
+    GvoModeData *data;
+    int rate;
+    char *name;
+
+
+    if (!gpu || table_idx >= gpu->num_gvo_modes) {
+        return FALSE;
+    }
+
+    data = &(gpu->gvo_mode_data[table_idx]);
+
+    ret1 = NvCtrlGetDisplayAttribute(gpu->handle,
+                                     mode_id,
+                                     NV_CTRL_GVO_VIDEO_FORMAT_REFRESH_RATE,
+                                     &(rate));
+    
+    ret2 = NvCtrlGetStringDisplayAttribute(gpu->handle,
+                                           mode_id,
+                                           NV_CTRL_STRING_GVO_VIDEO_FORMAT_NAME,
+                                           &(name));
+
+    if ((ret1 == NvCtrlSuccess) && (ret2 == NvCtrlSuccess)) {
+        data->id = mode_id;
+        data->rate = rate;
+        data->name = name;
+        return TRUE;
+    }
+
+    XFree(name);
+    return FALSE;
+}
+
+
 /** gpu_add_display_from_server() ************************************
  *
  *  Adds the display with the device mask given to the GPU structure.
@@ -1726,6 +1782,81 @@ nvDisplayPtr gpu_add_display_from_server(nvGpuPtr gpu,
     }
 
 
+    /* Query if this display is an SDI display */
+    ret = NvCtrlGetDisplayAttribute(gpu->handle, device_mask,
+                                    NV_CTRL_IS_GVO_DISPLAY,
+                                    &(display->is_sdi));
+    if (ret != NvCtrlSuccess) {
+        nv_warning_msg("Failed to query if display device\n"
+                       "0x%08x connected to GPU-%d '%s' is an\n"
+                       "SDI device.",
+                       device_mask, NvCtrlGetTargetId(gpu->handle),
+                       gpu->name);
+        display->is_sdi = FALSE;
+    }
+
+
+    /* Load the SDI mode table so we can report accurate refresh rates. */
+    if (display->is_sdi && !gpu->gvo_mode_data) {
+        unsigned int valid1 = 0;
+        unsigned int valid2 = 0;
+        NVCTRLAttributeValidValuesRec valid;
+
+        ret = NvCtrlGetValidAttributeValues(gpu->handle,
+                                            NV_CTRL_GVO_OUTPUT_VIDEO_FORMAT,
+                                            &valid);
+        if ((ret != NvCtrlSuccess) ||
+            (valid.type != ATTRIBUTE_TYPE_INT_BITS)) {
+            valid1 = 0;
+        } else {
+            valid1 = valid.u.bits.ints;
+        }
+        
+        ret = NvCtrlGetValidAttributeValues(gpu->handle,
+                                            NV_CTRL_GVO_OUTPUT_VIDEO_FORMAT2,
+                                            &valid);
+        if ((ret != NvCtrlSuccess) ||
+            (valid.type != ATTRIBUTE_TYPE_INT_BITS)) {
+            valid2 = 0;
+        } else {
+            valid2 = valid.u.bits.ints;
+        }
+
+        /* Count the number of valid modes there are */
+        gpu->num_gvo_modes = count_number_of_bits(valid1);
+        gpu->num_gvo_modes += count_number_of_bits(valid2);
+        if (gpu->num_gvo_modes > 0) {
+            gpu->gvo_mode_data = (GvoModeData *)calloc(gpu->num_gvo_modes,
+                                                       sizeof(GvoModeData));
+        }
+        if (!gpu->gvo_mode_data) {
+            gpu->num_gvo_modes = 0;
+        } else {
+            // Gather all the bits and dump them into the array
+            int idx = 0; // Index into gvo_mode_data.
+            int id = 0;  // Mode ID
+            while (valid1) {
+                if (valid1 & 1) {
+                    if (gpu_query_gvo_mode_info(gpu, id, idx)) {
+                        idx++;
+                    }
+                }
+                valid1 >>= 1;
+                id++;
+            }
+            while (valid2) {
+                if (valid2 & 1) {
+                    if (gpu_query_gvo_mode_info(gpu, id, idx)) {
+                        idx++;
+                    }
+                }
+                valid2 >>= 1;
+                id++;
+            }                
+        }
+    }
+
+
     /* Query the modelines for the display device */
     if (!display_add_modelines_from_server(display, err_str)) {
         nv_warning_msg("Failed to add modelines to display device 0x%08x "
@@ -1737,9 +1868,8 @@ nvDisplayPtr gpu_add_display_from_server(nvGpuPtr gpu,
 
 
     /* Add the display at the end of gpu's display list */
-    gpu->displays =
-        (nvDisplayPtr)xconfigAddListItem((GenericListPtr)gpu->displays,
-                                         (GenericListPtr)display);
+    xconfigAddListItem((GenericListPtr *)(&gpu->displays),
+                       (GenericListPtr)display);
     gpu->connected_displays |= device_mask;
     gpu->num_displays++;
     return display;
@@ -1811,9 +1941,8 @@ void gpu_remove_and_free_screen(nvScreenPtr screen)
         /* Remove the screen from the GPU */
         gpu = screen->gpu;
         
-        gpu->screens =
-            (nvScreenPtr)xconfigRemoveListItem((GenericListPtr)gpu->screens,
-                                               (GenericListPtr)screen);
+        xconfigRemoveListItem((GenericListPtr *)(&gpu->screens),
+                              (GenericListPtr)screen);
         gpu->num_screens--;
         
         /* Make sure other screens in the layout aren't relative
@@ -1963,9 +2092,8 @@ static int gpu_add_screen_from_server(nvGpuPtr gpu, int screen_id,
         }
     }
     /* Add the screen at the end of the gpu's screen list */
-    gpu->screens =
-        (nvScreenPtr)xconfigAddListItem((GenericListPtr)gpu->screens,
-                                        (GenericListPtr)screen);
+    xconfigAddListItem((GenericListPtr *)(&gpu->screens),
+                       (GenericListPtr)screen);
     gpu->num_screens++;
     return TRUE;
 
@@ -2256,8 +2384,8 @@ static Bool layout_add_gpu_from_server(nvLayoutPtr layout, unsigned int gpu_id,
 
 
     /* Add the GPU at the end of the layout's GPU list */
-    layout->gpus = (nvGpuPtr)xconfigAddListItem((GenericListPtr)layout->gpus,
-                                                (GenericListPtr)gpu);
+    xconfigAddListItem((GenericListPtr *)(&layout->gpus),
+                       (GenericListPtr)gpu);
     layout->num_gpus++;
     return TRUE;
 
