@@ -41,15 +41,15 @@
 #define X_nvCtrlSetGvoColorConversion_deprecated    7
 #define X_nvCtrlQueryGvoColorConversion_deprecated  8
 #define X_nvCtrlSetStringAttribute                  9
-#define X_nvCtrlQueryDDCCILutSize                   10
-#define X_nvCtrlQueryDDCCISinglePointLutOperation   11
-#define X_nvCtrlSetDDCCISinglePointLutOperation     12
-#define X_nvCtrlQueryDDCCIBlockLutOperation         13
-#define X_nvCtrlSetDDCCIBlockLutOperation           14
-#define X_nvCtrlSetDDCCIRemoteProcedureCall         15
-#define X_nvCtrlQueryDDCCIDisplayControllerType     16
-#define X_nvCtrlQueryDDCCICapabilities              17
-#define X_nvCtrlQueryDDCCITimingReport              18
+/* STUB X_nvCtrlQueryDDCCILutSize                   10 */
+/* STUB X_nvCtrlQueryDDCCISinglePointLutOperation   11 */
+/* STUB X_nvCtrlSetDDCCISinglePointLutOperation     12 */
+/* STUB X_nvCtrlQueryDDCCIBlockLutOperation         13 */
+/* STUB X_nvCtrlSetDDCCIBlockLutOperation           14 */
+/* STUB X_nvCtrlSetDDCCIRemoteProcedureCall         15 */
+/* STUB X_nvCtrlQueryDDCCIDisplayControllerType     16 */
+/* STUB X_nvCtrlQueryDDCCICapabilities              17 */
+/* STUB X_nvCtrlQueryDDCCITimingReport              18 */
 #define X_nvCtrlSetAttributeAndGetStatus            19
 #define X_nvCtrlQueryBinaryData                     20
 #define X_nvCtrlSetGvoColorConversion               21
@@ -371,231 +371,6 @@ typedef struct {
 } xnvCtrlQueryGvoColorConversionReply;
 #define sz_xnvCtrlQueryGvoColorConversionReply 32
 
-
-typedef struct {
-    CARD8 reqType;
-    CARD8 nvReqType;
-    CARD16 length B16;
-    CARD32 screen B32;
-    CARD32 display_mask B32;
-} xnvCtrlQueryDDCCILutSizeReq;
-#define sz_xnvCtrlQueryDDCCILutSizeReq 12
-
-typedef struct {
-    BYTE type;   /* X_Reply */
-    BYTE pad0;
-    CARD16 sequenceNumber B16;
-    CARD32 length B32;
-    CARD32 flags B32;
-    CARD32 pad4 B32;
-    CARD32 pad5 B32;
-    CARD32 pad6 B32;
-    CARD32 pad7 B32;
-    CARD32 pad8 B32;
-} xnvCtrlQueryDDCCILutSizeReply;
-#define sz_xnvCtrlQueryDDCCILutSizeReply 32
-
-typedef struct {
-    CARD8 reqType;
-    CARD8 nvReqType;
-    CARD16 length B16;
-    CARD32 screen B32;
-    CARD32 display_mask B32;
-    CARD32 offset B32;
-    CARD32 red_value B32;
-    CARD32 green_value B32;
-    CARD32 blue_value B32;
-} xnvCtrlSetDDCCISinglePointLutOperationReq;
-#define sz_xnvCtrlSetDDCCISinglePointLutOperationReq 28
-
-typedef struct {
-    BYTE type;   /* X_Reply */
-    BYTE pad0;
-    CARD16 sequenceNumber B16;
-    CARD32 length B32;
-    CARD32 flags B32;
-    CARD32 pad4 B32;
-    CARD32 pad5 B32;
-    CARD32 pad6 B32;
-    CARD32 pad7 B32;
-    CARD32 pad8 B32;
-} xnvCtrlSetDDCCISinglePointLutOperationReply;
-#define sz_xnvCtrlSetDDCCISinglePointLutOperationReply 32
-
-typedef struct {
-    CARD8 reqType;
-    CARD8 nvReqType;
-    CARD16 length B16;
-    CARD32 screen B32;
-    CARD32 display_mask B32;
-    CARD32 offset B32;
-} xnvCtrlQueryDDCCISinglePointLutOperationReq;
-#define sz_xnvCtrlQueryDDCCISinglePointLutOperationReq 16
-
-typedef struct {
-    BYTE type;   /* X_Reply */
-    BYTE pad0;
-    CARD16 sequenceNumber B16;
-    CARD32 length B32;
-    CARD32 flags B32;
-    CARD32 pad4 B32;
-    CARD32 pad5 B32;
-    CARD32 pad6 B32;
-    CARD32 pad7 B32;
-    CARD32 pad8 B32;
-} xnvCtrlQueryDDCCISinglePointLutOperationReply;
-#define sz_xnvCtrlQueryDDCCISinglePointLutOperationReply 32
-
-typedef struct {
-    CARD8 reqType;
-    CARD8 nvReqType;
-    CARD16 length B16;
-    CARD32 screen B32;
-    CARD32 display_mask B32;
-    CARD32 size B32;
-    CARD32 color B32;
-    CARD32 offset B32;
-} xnvCtrlQueryDDCCIBlockLutOperationReq;
-#define sz_xnvCtrlQueryDDCCIBlockLutOperationReq 24
-
-typedef struct {
-    BYTE type;   /* X_Reply */
-    BYTE pad0;
-    CARD16 sequenceNumber B16;
-    CARD32 length B32;
-    CARD32 num_bytes B32;
-    CARD32 flags B32;
-    CARD32 pad5 B32;
-    CARD32 pad6 B32;
-    CARD32 pad7 B32;
-    CARD32 pad8 B32;
-} xnvCtrlQueryDDCCIBlockLutOperationReply;
-#define sz_xnvCtrlQueryDDCCIBlockLutOperationReply 32
-
-
-typedef struct {
-    CARD8 reqType;
-    CARD8 nvReqType;
-    CARD16 length B16;
-    CARD32 screen B32;
-    CARD32 display_mask B32;
-    CARD32 color B32;
-    CARD32 offset B32;
-    CARD32 size B32;
-    CARD32 num_bytes B32;
-} xnvCtrlSetDDCCIBlockLutOperationReq;
-#define sz_xnvCtrlSetDDCCIBlockLutOperationReq 28
-
-typedef struct {
-    BYTE type;   /* X_Reply */
-    BYTE pad0;
-    CARD16 sequenceNumber B16;
-    CARD32 length B32;
-    CARD32 num_bytes B32;
-    CARD32 flags B32;
-    CARD32 pad5 B32;
-    CARD32 pad6 B32;
-    CARD32 pad7 B32;
-    CARD32 pad8 B32;
-} xnvCtrlSetDDCCIBlockLutOperationReply;
-#define sz_xnvCtrlSetDDCCIBlockLutOperationReply 32
-
-
-typedef struct {
-    CARD8 reqType;
-    CARD8 nvReqType;
-    CARD16 length B16;
-    CARD32 screen B32;
-    CARD32 display_mask B32;
-    CARD32 num_bytes B32;
-    CARD32 size B32;
-    CARD32 offset B32;
-} xnvCtrlSetDDCCIRemoteProcedureCallReq;
-#define sz_xnvCtrlSetDDCCIRemoteProcedureCallReq 24
-
-typedef struct {
-    BYTE type;   /* X_Reply */
-    BYTE pad0;
-    CARD16 sequenceNumber B16;
-    CARD32 length B32;
-    CARD32 num_bytes B32;
-    CARD32 flags B32;
-    CARD32 pad5 B32;
-    CARD32 pad6 B32;
-    CARD32 pad7 B32;
-    CARD32 pad8 B32;
-} xnvCtrlSetDDCCIRemoteProcedureCallReply;
-#define sz_xnvCtrlSetDDCCIRemoteProcedureCallReply 32
-
-typedef struct {
-    CARD8 reqType;
-    CARD8 nvReqType;
-    CARD16 length B16;
-    CARD32 screen B32;
-    CARD32 display_mask B32;
-} xnvCtrlQueryDDCCIDisplayControllerTypeReq;
-#define sz_xnvCtrlQueryDDCCIDisplayControllerTypeReq 12
-
-typedef struct {
-    BYTE type;   /* X_Reply */
-    BYTE pad0;
-    CARD16 sequenceNumber B16;
-    CARD32 length B32;
-    CARD32 controller_type B32;
-    CARD32 size B32;
-    CARD32 flags B32;
-    CARD32 pad5 B32;
-    CARD32 pad6 B32;
-    CARD32 pad7 B32;
-} xnvCtrlQueryDDCCIDisplayControllerTypeReply;
-#define sz_xnvCtrlQueryDDCCIDisplayControllerTypeReply 32
-
-typedef struct {
-    CARD8 reqType;
-    CARD8 nvReqType;
-    CARD16 length B16;
-    CARD32 screen B32;
-    CARD32 display_mask B32;
-} xnvCtrlQueryDDCCICapabilitiesReq;
-#define sz_xnvCtrlQueryDDCCICapabilitiesReq 12
-
-typedef struct {
-    BYTE type;   /* X_Reply */
-    BYTE pad0;
-    CARD16 sequenceNumber B16;
-    CARD32 length B32;
-    CARD32 num_bytes B32;
-    CARD32 flags B32;
-    CARD32 possible_val_len B32;
-    CARD32 pad6 B32;
-    CARD32 pad7 B32;
-    CARD32 pad8 B32;
-} xnvCtrlQueryDDCCICapabilitiesReply;
-#define sz_xnvCtrlQueryDDCCICapabilitiesReply 32
-
-typedef struct {
-    CARD8 reqType;
-    CARD8 nvReqType;
-    CARD16 length B16;
-    CARD32 screen B32;
-    CARD32 display_mask B32;
-} xnvCtrlQueryDDCCITimingReportReq;
-#define sz_xnvCtrlQueryDDCCITimingReportReq 12
-
-typedef struct {
-    BYTE type;   /* X_Reply */
-    BYTE pad0;
-    CARD16 sequenceNumber B16;
-    CARD32 length B32;
-    CARD32 flags B32;
-    CARD32 pad4 B32;
-    CARD32 pad5 B32;
-    CARD32 pad6 B32;
-    CARD32 pad7 B32;
-    CARD32 pad8 B32;
-} xnvCtrlQueryDDCCITimingReportReply;
-#define sz_xnvCtrlQueryDDCCITimingReportReply 32
-
 typedef struct {
     CARD8 reqType;
     CARD8 nvReqType;
